@@ -1,5 +1,6 @@
 import http from 'k6/http';
-import { sleep, check } from 'k6';
+import { sleep } from 'k6';
+import { expect } from "https://jslib.k6.io/k6-testing/0.5.0/index.js";
 
 export const options = {
   vus: 10,
@@ -12,6 +13,6 @@ export const options = {
 
 export default function() {
   let res = http.get('https://quickpizza.grafana.com');
-  check(res, { "status is 200": (res) => res.status === 200 });
+  expect.soft(res.status).toBe(200);
   sleep(1);
 }
