@@ -7,20 +7,17 @@ import (
 )
 
 // mapMetricEvent to the JS module.
-func mapMetricEvent(vu moduleVU, event common.PageOnEvent) mapping {
+func mapMetricEvent(vu moduleVU, event common.PageEvent) mapping {
 	rt := vu.Runtime()
 	em := event.Metric
 
 	return mapping{
 		"tag": func(urls common.TagMatches) error {
 			callback := func(pattern, url string) (bool, error) {
-				js := fmt.Sprintf(`_k6BrowserCheckRegEx(%s, '%s')`, pattern, url)
-
-				matched, err := rt.RunString(js)
+				matched, err := rt.RunString(pattern + `.test('` + url + `')`)
 				if err != nil {
 					return false, fmt.Errorf("matching url with regex: %w", err)
 				}
-
 				return matched.ToBoolean(), nil
 			}
 
