@@ -60,7 +60,7 @@ func testOutputCycle(t testing.TB, handler http.HandlerFunc, body func(testing.T
 		MaxHeaderBytes:    1 << 20,
 		ReadHeaderTimeout: time.Second,
 	}
-	l, err := net.Listen("tcp", "127.0.0.1:0")
+	l, err := (&net.ListenConfig{}).Listen(context.Background(), "tcp", "127.0.0.1:0")
 	require.NoError(t, err)
 	defer func() {
 		_ = l.Close()
